@@ -7,6 +7,7 @@ from kdp_connector.connectors.kdp_api import KdpApi
 from kdp_connector.connectors.query import QueryApi
 from kdp_connector.connectors.index_management import IndexManagementApi
 from kdp_connector.connectors.upload import UploadApi
+from kdp_api.models import SecurityLabelInfoParams
 
 
 class KdpConn(object):
@@ -89,6 +90,34 @@ class KdpConn(object):
         config = self.create_configuration(jwt)
         return write_api.batch_write(config=config, dataset_id=dataset_id, dataframe=dataframe, batch_size=batch_size, is_async=is_async)
 
+
+    # WRITE
+    def batch_write_v2(self, dataframe, dataset_id: str, jwt: str, security_label_info_params: SecurityLabelInfoParams = None, batch_size: int = 100, is_async: bool = True):
+        """This method will be used to write batches of data to KDP
+
+            :param DataFrame dataframe: Data to write to KDP
+            :param str dataset_id: ID of the KDP dataset where the data will be written
+            :param str jwt: JWT token
+            :param SecurityLabelInfoParams security_label_info_params: Security Label Parser Parameter configuration
+            :param int batch_size: Defaults to 100
+            :param bool is_async: Defaults to True
+
+            :returns: Set of partitions data was written to
+
+            :rtype: set
+        """
+        write_api = WriteApi()
+        config = self.create_configuration(jwt)
+        return write_api.batch_write_v2(
+            config=config,
+            dataset_id=dataset_id,
+            dataframe=dataframe,
+            security_label_info_params=security_label_info_params,
+            batch_size=batch_size,
+            is_async=is_async)
+
+
+
     def create_url_ingest_job(self, workspace_id: str, dataset_id: str, url_list, jwt: str) -> str:
         """This method will be used to start a job that ingests files to KDP
 
